Py PNG Distill
==============

PNGs are all over the place. Unfortunately, they're usually bloated with unecessary and poorly compressed data. This package aims to help you fix that by giving you what you need to distill your files to the smallest possible size before serving them. All you need to do is call distill with either a filename to open or an already opened file.
